function raw2centroids(LaserFile, BGndFile, OutputFile)
% RAW2CENTROIDS  First step in reducing BTO quad cell data
%
%   Subtracts background, computes centroids, converts to
%   BTO global axis and sign conventions, scales centroids
%   to mm and sum signal to volts, writes result to file.
%   C. Shelton 9/29/2005
%

%  Load ascii raw data file
data = load(LaserFile);

%  Subtract background
bg = load(BGndFile);
npts = size(data,1)
e = ones(npts,1);
bgnd = e*mean(bg);
data = data - bgnd;

%  Swap Q2 x and y
temp = data(:,4);
data(:,4) = data(:,5);
data(:,5) = temp;

%  Enforce minimum divisor (sum signal)
minSum = 10.0;
norm1 = data(:,3);
norm1(norm1<minSum) = minSum;
norm2 = data(:,6);
norm2(norm2<minSum) = minSum;
norm3 = data(:,9);
norm3(norm3<minSum) = minSum;

%  Divide by sum signal, change 
%    signs to conform to
%    global sign convention
data(:,1) = +data(:,1)./norm1;
data(:,2) = -data(:,2)./norm1;
data(:,4) = -data(:,4)./norm2;
data(:,5) = -data(:,5)./norm2;
data(:,7) = -data(:,7)./norm3;
data(:,8) = -data(:,8)./norm3;

%  Constrain centroids to range
%  -1.0 to +1.0
c = [1 2 4 5 7 8];
for i = 1:4
  j = c(i);
  data((data(:,j)<-1.0)) = -1.0;
  data((data(:,j)>+1.0)) = +1.0;
end

%  Scale centroids to millimeters
%  Scale sum signal to volts
scaling = [1/0.489961,
    1/0.191468,
    10.0/32768,
    1/0.520205,
    1/0.520205,
    10.0/32768,
    1/0.522235,
    1/0.179585,
    10.0/32768];
scale = e * scaling';
data = data .* scale;

%  Write results to file
save(OutputFile,'data');
%save('test.txt','data', '-ascii', '-tabs');

