/*
 * Read BTO text files and translate to .MAT format
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "mat.h"


#define MAXLINES (500*180) // 3 minutes
#define MAXPTS (500*180*9)

int buf[MAXPTS];

void p_error(char errstr[])
{
   char ss[256];
   
   puts(errstr);
   fgets(ss, strlen(ss), stdin);
   exit(EXIT_FAILURE);
}

void readTextFile(char *fspec, int *nlines)
{
  FILE *fp;
  char ss[256];
  int i;

  if ((fp = fopen(fspec,"rt")) == NULL) {
     sprintf(ss, "Can't open %s for reading\n",fspec);
     p_error(ss) ;
  }
  i = 0;
  while (!feof(fp) && (i<MAXPTS))
  {
     if (9 != fscanf(fp, "%d %d %d %d %d %d %d %d %d", &buf[i], &buf[i+1],
        &buf[i+2], &buf[i+3], &buf[i+4], &buf[i+5],
        &buf[i+6], &buf[i+7], &buf[i+8]))
     break; else i += 9;
  }
  fclose(fp);
  *nlines = i/9;
} /* readTextFile */


int main(int argc, char *argv[])
{
   char ss[256], fname[256];
   char* ext = ".MAT";
   int nlines;
   MATFile *pmat;
   mxArray *pa;
   int status;

   if (argc != 2) {
      printf("\n   Usage: text2mat <fname>\n");
      printf("  Translates <fname> into <fname>.mat \n");
      return(EXIT_FAILURE);
   }
   printf("Reading text file %s\n", argv[1]);
   readTextFile(argv[1], &nlines);
   printf("Done, lines read = %d\n", nlines);

   strcpy(fname, argv[1]);
   strcat(fname, ext);
   printf("Creating file %s\n", fname);

   pmat = matOpen(fname, "w");
   if (pmat == NULL) {
      printf("Error creating file %s\n", fname);
      printf("(Do you have write permission in this directory?)\n");
      return(EXIT_FAILURE);
   }

  pa = mxCreateDoubleMatrix(9,nlines,mxREAL);
  if (pa == NULL) {
      printf("%s : Out of memory on line %d\n", __FILE__, __LINE__);
      printf("Unable to create mxArray.\n");
      return(EXIT_FAILURE);
   }
   
   memcpy((void *)(mxGetPr(pa)), (void *)buf, sizeof(buf));

   status = matPutVariable(pmat, "LocalDouble", pa);
   if (status != 0) {
      printf("%s :  Error using matPutVariable on line %d\n", __FILE__, __LINE__);
      return(EXIT_FAILURE);
   }

   mxDestroyArray(pa);

   if (matClose(pmat) != 0) {
      printf("Error closing file %s\n",fname);
      return(EXIT_FAILURE);
   }
   
   printf("Done\n");
   fgets(ss, strlen(ss), stdin);
   return(EXIT_SUCCESS);
}

