//=======================================================================
//
// NAME:    pd_hcaps.h
//
// SYNOPSIS:
//
//      Capabilities definition header file of UEI PowerDAQ DLL
//
//
// DESCRIPTION:
//
//      This file contains board capabilities structure
//
// AUTHOR: Frederic Villeneuve 
//         Alex Ivchenko
//
//---------------------------------------------------------------------------
//      Copyright (C) 2000,2004 United Electronic Industries, Inc.
//      All rights reserved.
//---------------------------------------------------------------------------
// For more informations on using and distributing this software, please see
// the accompanying "LICENSE" file.
//
//-----------------------------------------------------------------------

#include "powerdaq32.h"


const DAQ_Information DAQ_Info[PD_BRD_LST+1] =
{
// PowerDAQ series
//
// 12-bit multifunction medium speed (330 kHz)
    {
      0x101,
      "PD-MF-16-330/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      330000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

  {
      0x102,
      "PD-MF-16-330/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      330000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

  {
      0x103,
      "PD-MF-64-330/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      330000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

  {
      0x104,
      "PD-MF-64-330/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      330000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

// 12-bit multifunction high speed (1 MHz)
  {
      0x105,
      "PD-MF-16-1M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

  {
      0x106,
      "PD-MF-16-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

  {
      0x107,
      "PD-MF-64-1M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

  {
      0x108,
      "PD-MF-64-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },

// 16-bit multifunction (250 kHz)
    {
      0x109,
      "PD-MF-16-250/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x10A,
      "PD-MF-16-250/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x10B,
      "PD-MF-64-250/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x10C,
      "PD-MF-64-250/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
// 16-bit multifunction (50 kHz)
    {
      0x10D,
      "PD-MF-16-50/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x10E,
      "PD-MF-16-50/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  // 6 channels SSH
  {
      0x10F,
      "PD-MFS-6-1M/12",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:05 12:AO:0:01 8:DI:0:0 8:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x800,
      0xFFF
  },
  // Not assigned. dummy.
  {
      0x110,
      "Not assigned",
      "No",
      "No",
      "No",
      "No",
      "No",
      "No",
      "No",
      0,
      "No",
      0,
      "No",
      0,
      0,
      0,
      0
  },

// PowerDAQ II series
//
// 14-bit multifunction low speed (400 kHz)
    {
      0x111,
      "PD2-MF-16-400/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x112,
      "PD2-MF-16-400/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
    },

    {
      0x113,
      "PD2-MF-64-400/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x114,
      "PD2-MF-64-400/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 14-bit multifunction medium speed (800 kHz)
    {
      0x115,
      "PD2-MF-16-800/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x116,
      "PD2-MF-16-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

    {
      0x117,
      "PD2-MF-64-800/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x118,
      "PD2-MF-64-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },


// 12-bit multifunction high speed (1 MHz)
    {
      0x119,
      "PD2-MF-16-1M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x11A,
      "PD2-MF-16-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

    {
      0x11B,
      "PD2-MF-64-1M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x11C,
      "PD2-MF-64-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

// 16-bit multifunction (50 kHz)
    {
      0x11D,
      "PD2-MF-16-50/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x11E,
      "PD2-MF-16-50/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x11F,
      "PD2-MF-64-50/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x120,
      "PD2-MF-64-50/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// 16-bit multifunction (333 kHz)
  {
      0x121,
      "PD2-MF-16-333/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x122,
      "PD2-MF-16-333/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

    {
      0x123,
      "PD2-MF-64-333/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x124,
      "PD2-MF-64-333/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// 14-bit multifunction high speed (2.2 MHz)
    {
      0x125,
      "PD2-MF-16-2M/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x126,
      "PD2-MF-16-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x127,
      "PD2-MF-64-2M/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x128,
      "PD2-MF-64-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 16-bit multifunction high speed (500 kHz)

  {
      0x129,
      "PD2-MF-16-500/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x12A,
      "PD2-MF-16-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

    {
      0x12B,
      "PD2-MF-64-500/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x12C,
      "PD2-MF-64-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// PowerDAQ II SSH section ---------------------
// 14-bit multifunction SSH low speed (500 kHz)
    {
      0x12D,
      "PD2-MFS-4-500/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x12E,
      "PD2-MFS-8-500/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x12F,
      "PD2-MFS-4-500/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x130,
      "PD2-MFS-4-500/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x131,
      "PD2-MFS-8-500/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x132,
      "PD2-MFS-8-500/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 14-bit multifunction SSH medium speed (800 kHz)
    {
      0x133,
      "PD2-MFS-4-800/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x134,
      "PD2-MFS-8-800/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x135,
      "PD2-MFS-4-800/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x136,
      "PD2-MFS-4-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x137,
      "PD2-MFS-8-800/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x138,
      "PD2-MFS-8-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 12-bit multifunction SSH high speed (1.25 MHz)
    {
      0x139,
      "PD2-MFS-4-1M/12",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x13A,
      "PD2-MFS-8-1M/12",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x13B,
      "PD2-MFS-4-1M/12DG",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x13C,
      "PD2-MFS-4-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x13D,
      "PD2-MFS-8-1M/12DG",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x13E,
      "PD2-MFS-8-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

// 14-bit multifunction SSH high speed (2.2 MHz)

    {
      0x13F,
      "PD2-MFS-4-2M/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x140,
      "PD2-MFS-8-2M/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x141,
      "PD2-MFS-4-2M/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x142,
      "PD2-MFS-4-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x143,
      "PD2-MFS-8-2M/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x144,
      "PD2-MFS-8-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 16-bit multifunction SSH high speed (333 kHz)

    {
      0x145,
      "PD2-MFS-4-300/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x146,
      "PD2-MFS-8-300/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x147,
      "PD2-MFS-4-300/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x148,
      "PD2-MFS-4-300/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x149,
      "PD2-MFS-8-300/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x14A,
      "PD2-MFS-8-300/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// DIO series

  {
      0x14B,
      "PD2-DIO-64",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x14C,
      "PD2-DIO-128",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x14D,
      "PD2-DIO-256",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:15 16:DO:0:15 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

// AO series

  {
      0x14E,
      "PD2-AO-8/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:7 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  {
      0x14F,
      "PD2-AO-16/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:15 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  {
      0x150,
      "PD2-AO-32/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  {
      0x151,
      "PD2-AO-96/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:95 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x152,
      "PD2-AO-32/16HC",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x153,
      "PD2-AO-32/16HV",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B40",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x154,
      "PD2-AO-96/16HS",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:95 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x155,
      "PD2-AO-8/16HSG",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:7 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x156,
      "PD2-AO-R5",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x157,
      "PD2-AO-R6",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x158,
      "PD2-AO-R7",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  // extended DIO series

  {
      0x159,
      "PD2-DIO-64CE",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x15A,
      "PD2-DIO-128CE",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x15B,
      "PD2-DIO-64ST",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x15C,
      "PD2-DIO-128ST",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x15D,
      "PD2-DIO-64HS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x15E,
      "PD2-DIO-128HS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x15F,
      "PD2-DIO-64CT",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x160,
      "PD2-DIO-128CT",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x161,
      "PD2-DIO-64TS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1600000,
      0x0,
      0x0
  },
  {
      0x162,
      "PD2-DIO-128TS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1600000,
      0x0,
      0x0
  },
  {
      0x163,
      "PD2-DIO-R2",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x164,
      "PD2-DIO-R3",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x165,
      "PD2-DIO-R4",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x166,
      "PD2-DIO-R5",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x167,
      "PD2-DIO-R6",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x168,
      "PD2-DIO-R7",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  // 16-bit multifunction SSH high speed (500 kHz)

    {
      0x169,
      "PD2-MFS-4-500/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x16A,
      "PD2-MFS-8-500/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x16B,
      "PD2-MFS-4-500/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x16C,
      "PD2-MFS-4-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x16D,
      "PD2-MFS-8-500/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x16E,
      "PD2-MFS-8-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// 16-bit multifunction (100 kHz)
  {
      0x16F,
      "PD2-MF-16-150/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x170,
      "PD2-MF-16-150/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

    {
      0x171,
      "PD2-MF-64-150/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x172,
      "PD2-MF-64-150/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  // 12-bit multifunction high speed (3MHz)
  {
      0x173,
      "PD2-MF-16-3M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x174,
      "PD2-MF-64-3M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },
  {
      0x175,
      "PD2-MF-16-3M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:16 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },
  {
      0x176,
      "PD2-MF-64-3M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },
  // 16-bit high high speed multifunction
  {
      0x177,
      "PD2-MF-16-4M/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      4000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x178,
      "PD2-MF-64-4M/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      4000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x179,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x17A,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x17B,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x17C,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x17D,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x17E,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x17F,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x180,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x181,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x182,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "56301",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x183,
      "PDL-MF-16-50/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 24:DI:0:0 24:DO:0:0 24:CT:0:01",
      "S X",
      "0 SB5 SU10 SB10 0 DB5 DU10 DB10 ",
      "1 2 5 10",
      "INT BM",
      50000,
      "B10",
      100000,
      "MOT56301",
      1000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x184,
      "PDL-MF-16-100/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 24:DI:0:0 24:DO:0:0 24:CT:0:01",
      "S X",
      "0 SB5 SU10 SB10 0 DB5 DU10 DB10 ",
      "1 2 5 10",
      "INT BM",
      100000,
      "B10",
      100000,
      "MOT56301",
      1000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x185,
      "PDL-MF-16-160/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 24:DI:0:0 24:DO:0:0 24:CT:0:01",
      "S X",
      "0 SB5 SU10 SB10 0 DB5 DU10 DB10 ",
      "1 2 5 10",
      "INT BM",
      160000,
      "B10",
      100000,
      "MOT56301",
      1000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x186,
      "PDL-MF-16-50/16TSG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SB5 SU10 SB10 DU5 DB5 DU10 DB10 ",
      "1 2 4 8",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x187,
      "PDL-DIO-64",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x188,
      "PDL-DIO-64ST",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x189,
      "PDL-DIO-64CT",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1600000,
      0x0,
      0x0
  },
  {
      0x18A,
      "PDL-DIO-64TS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1600000,
      0x0,
      0x0           
  },

  { 0x18B,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x18C,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x18D,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x18E,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },  
  { 0x18F,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x190,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x191,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x192,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x193,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x194,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x195,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x196,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x197,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x198,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x199,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x19A,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x19B,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x19C,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x19D,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x19E,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x19F,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x1a0,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a1,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a2,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a3,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a4,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a5,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a6,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a7,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a8,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1a9,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1aA,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1aB,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1aC,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1aD,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1aE,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1aF,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x1b0,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b1,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b2,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b3,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b4,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b5,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b6,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b7,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b8,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1b9,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1bA,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1bB,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1bC,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1bD,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1bE,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1bF,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x1c0,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c1,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c2,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c3,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c4,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c5,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c6,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c7,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c8,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1c9,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1cA,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1cB,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1cC,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1cD,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1cE,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1cF,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x1d0,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d1,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d2,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d3,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d4,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d5,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d6,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d7,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d8,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1d9,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1dA,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1dB,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1dC,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1dD,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1dE,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1dF,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x1e0,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e1,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e2,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e3,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e4,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e5,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e6,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e7,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e8,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1e9,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1eA,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1eB,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1eC,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1eD,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1eE,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1eF,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x1f0,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f1,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f2,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f3,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f4,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f5,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f6,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f7,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f8,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1f9,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1fA,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1fB,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1fC,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1fD,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1fE,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x1fF,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

  { 0x200,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x201,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x202,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x203,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x204,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x205,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x206,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x207,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x208,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x209,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x20A,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x20B,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x20C,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x20D,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x20E,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x20F,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x210,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },

// PowerDAQ II series
//
// 14-bit multifunction low speed (400 kHz)
    {
      0x211,
      "PDXI-MF-16-400/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x212,
      "PDXI-MF-16-400/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
    },

    {
      0x213,
      "PDXI-MF-64-400/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x214,
      "PDXI-MF-64-400/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      400000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 14-bit multifunction medium speed (800 kHz)
    {
      0x215,
      "PDXI-MF-16-800/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x216,
      "PDXI-MF-16-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

    {
      0x217,
      "PDXI-MF-64-800/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x218,
      "PDXI-MF-64-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },


// 12-bit multifunction high speed (1 MHz)
    {
      0x219,
      "PDXI-MF-16-1M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x21A,
      "PDXI-MF-16-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

    {
      0x21B,
      "PDXI-MF-64-1M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x21C,
      "PDXI-MF-64-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

// 16-bit multifunction (50 kHz)
    {
      0x21D,
      "PDXI-MF-16-50/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x21E,
      "PDXI-MF-16-50/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x21F,
      "PDXI-MF-64-50/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x220,
      "PDXI-MF-64-50/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      50000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// 16-bit multifunction (333 kHz)
  {
      0x221,
      "PDXI-MF-16-333/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x222,
      "PDXI-MF-16-333/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

    {
      0x223,
      "PDXI-MF-64-333/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x224,
      "PDXI-MF-64-333/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// 14-bit multifunction high speed (2.2 MHz)
    {
      0x225,
      "PDXI-MF-16-2M/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x226,
      "PDXI-MF-16-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x227,
      "PDXI-MF-64-2M/14L",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x228,
      "PDXI-MF-64-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 16-bit multifunction high speed (500 kHz)

  {
      0x229,
      "PDXI-MF-16-500/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x22A,
      "PDXI-MF-16-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

    {
      0x22B,
      "PDXI-MF-64-500/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x22C,
      "PDXI-MF-64-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// PowerDAQ II SSH section ---------------------
// 14-bit multifunction SSH low speed (400 kHz)
    {
      0x22D,
      "PDXI-MFS-4-500/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x22E,
      "PDXI-MFS-8-500/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x22F,
      "PDXI-MFS-4-500/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x230,
      "PDXI-MFS-4-500/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x231,
      "PDXI-MFS-8-500/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x232,
      "PDXI-MFS-8-500/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 14-bit multifunction SSH medium speed (800 kHz)
    {
      0x233,
      "PDXI-MFS-4-800/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x234,
      "PDXI-MFS-8-800/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x235,
      "PDXI-MFS-4-800/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x236,
      "PDXI-MFS-4-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x237,
      "PDXI-MFS-8-800/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x238,
      "PDXI-MFS-8-800/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      800000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 12-bit multifunction SSH high speed (1.25 MHz)
    {
      0x239,
      "PDXI-MFS-4-1M/12",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x23A,
      "PDXI-MFS-8-1M/12",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x23B,
      "PDXI-MFS-4-1M/12DG",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x23C,
      "PDXI-MFS-4-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x23D,
      "PDXI-MFS-8-1M/12DG",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x23E,
      "PDXI-MFS-8-1M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      1250000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

// 14-bit multifunction SSH high speed (2.2 MHz)

    {
      0x23F,
      "PDXI-MFS-4-2M/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x240,
      "PDXI-MFS-8-2M/14",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x241,
      "PDXI-MFS-4-2M/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x242,
      "PDXI-MFS-4-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x243,
      "PDXI-MFS-8-2M/14DG",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

  {
      0x244,
      "PDXI-MFS-8-2M/14H",
      "PCI",
      "MOT56301 24KI",
      "14:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      2200000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFC
  },

// 16-bit multifunction SSH high speed (333 kHz)

    {
      0x245,
      "PDXI-MFS-4-300/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x246,
      "PDXI-MFS-8-300/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x247,
      "PDXI-MFS-4-300/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x248,
      "PDXI-MFS-4-300/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x249,
      "PDXI-MFS-8-300/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x24A,
      "PDXI-MFS-8-300/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// DIO series

  {
      0x24B,
      "PDXI-DIO-64",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x24C,
      "PDXI-DIO-128",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x24D,
      "PDXI-DIO-256",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:15 16:DO:0:15 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

// AO series

  {
      0x24E,
      "PDXI-AO-8/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:7 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  {
      0x24F,
      "PDXI-AO-16/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:15 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  {
      0x250,
      "PDXI-AO-32/16",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  {
      0x251,
      "PDXI-AO-R0",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      100000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x252,
      "PDXI-AO-R1",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x253,
      "PDXI-AO-R2",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x254,
      "PDXI-AO-R3",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x255,
      "PDXI-AO-R4",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x256,
      "PDXI-AO-R5",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x257,
      "PDXI-AO-R6",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },
  {
      0x258,
      "PDXI-AO-R7",
      "PCI",
      "MOT56301 24KI",
      "16:AO:0:31 8:DI:0:0 8:DO:0:0 24:CT:0:02 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "B10",
      200000,
      "MOT56301",
      0,
      0,
      0,
      0
  },

  // extended DIO series

  {
      0x259,
      "PDXI-DIO-64CE",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x25A,
      "PDXI-DIO-128CE",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x25B,
      "PDXI-DIO-64ST",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x25C,
      "PDXI-DIO-128ST",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x25D,
      "PDXI-DIO-64HS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x25E,
      "PDXI-DIO-128HS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x25F,
      "PDXI-DIO-64CT",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x260,
      "PDXI-DIO-128CT",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  {
      0x261,
      "PDXI-DIO-64TS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1600000,
      0x0,
      0x0
  },

  {
      0x262,
      "PDXI-DIO-128TS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1600000,
      0x0,
      0x0
  },

  {
      0x263,
      "PDXI-DIO-R2",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x264,
      "PDXI-DIO-R3",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x265,
      "PDXI-DIO-R4",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x266,
      "PDXI-DIO-R5",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x267,
      "PDXI-DIO-R6",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x268,
      "PDXI-DIO-R7",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:7 16:DO:0:7 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  // 16-bit multifunction SSH high speed (500 kHz)

    {
      0x269,
      "PDXI-MFS-4-500/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x26A,
      "PDXI-MFS-8-500/16",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10",
      "1 1 1 1",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x26B,
      "PDXI-MFS-4-500/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x26C,
      "PDXI-MFS-4-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:3 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x26D,
      "PDXI-MFS-8-500/16DG",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 5 10",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x26E,
      "PDXI-MFS-8-500/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:7 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      500000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

// 16-bit multifunction (200 kHz)
  {
      0x26F,
      "PDXI-MF-16-150/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x270,
      "PDXI-MF-16-150/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

    {
      0x271,
      "PDXI-MF-64-150/16L",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  {
      0x272,
      "PDXI-MF-64-150/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      150000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },

  // 12-bit multifunction high speed (3MHz)
  {
      0x273,
      "PDXI-MF-16-3M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },

  {
      0x274,
      "PDXI-MF-64-3M/12H",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },
  {
      0x175,
      "PD2-MF-16-3M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:16 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },
  {
      0x276,
      "PDXI-MF-64-3M/12L",
      "PCI",
      "MOT56301 24KI",
      "12:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 10 100 1000",
      "INT BM",
      3000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFF0
  },
  // 16-bit high high speed multifunction
  {
      0x277,
      "PDXI-MF-16-4M/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      4000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x278,
      "PDXI-MF-64-4M/16H",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      4000000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x279,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x27A,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x27B,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x27C,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x27D,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x27E,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x27F,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x280,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x281,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x282,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SU10 SB5 SB10 DU5 DU10 DB5 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x283,
      "PDXL-MF-16-50/16",
      "PXI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 24:DI:0:0 24:DO:0:0 24:CT:0:01",
      "S X",
      "0 SB5 SU10 SB10 0 DB5 DU10 DB10 ",
      "1 2 5 10",
      "INT BM",
      50000,
      "B10",
      100000,
      "MOT56301",
      1000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x284,
      "PDXL-MF-16-100/16",
      "PXI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 24:DI:0:0 24:DO:0:0 24:CT:0:01",
      "S X",
      "0 SB5 SU10 SB10 0 DB5 DU10 DB10 ",
      "1 2 5 10",
      "INT BM",
      100000,
      "B10",
      100000,
      "MOT56301",
      1000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x285,
      "PDXL-MF-16-160/16",
      "PXI",
      "MOT56301 24KI",
      "16:AI:0:15 12:AO:0:01 24:DI:0:0 24:DO:0:0 24:CT:0:01",
      "S X",
      "0 SB5 SU10 SB10 0 DB5 DU10 DB10 ",
      "1 2 5 10",
      "INT BM",
      160000,
      "B10",
      100000,
      "MOT56301",
      1000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x286,
      "reserved",
      "PCI",
      "MOT56301 24KI",
      "16:AI:0:63 12:AO:0:01 16:DI:0:0 16:DO:0:0 16:CT:0:02",
      "S X",
      "SU5 SB5 SU10 SB10 DU5 DB5 DU10 DB10 ",
      "1 2 4 8",
      "INT BM",
      333000,
      "B10",
      200000,
      "82C54",
      8000000,
      1000000,
      0x8000,
      0xFFFF
  },
  {
      0x287,
      "PDXL-DIO-64",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x288,
      "PDXL-DIO-64ST",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x289,
      "PDXL-DIO-64CT",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },
  {
      0x28A,
      "PDXL-DIO-64TS",
      "PCI",
      "MOT56301 24KI",
      "16:DI:0:3 16:DO:0:3 24:CT:0:2 0:SI:0:1",
      "S X",
      "No",
      "No",
      "INT BM",
      0,
      "No",
      0,
      "MOT56301",
      33000000,
      1000000,
      0x0,
      0x0
  },

  { 0x28B,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x28C,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x28D,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 },
  { 0x28E,"x","x","x","x","x","x","x","x", 0,"x", 0,"x", 0, 0, 0, 0 }, 


};



