//===========================================================================
//
// NAME:    pdcmd.h
//
// DESCRIPTION:
//
//          PowerDAQ Linux ioctl argument casting definitions
//
//
// AUTHOR: Frederic Villeneuve 
//         Alex Ivchenko and Sebastian Kuzminski
//
//---------------------------------------------------------------------------
//      Copyright (C) 2000,2004 United Electronic Industries, Inc.
//      All rights reserved.
//---------------------------------------------------------------------------
// For more informations on using and distributing this software, please see
// the accompanying "LICENSE" file.


#ifndef  __PDCMD_H__
#define  __PDCMD_H__

//
// File contains structures to perform requests to the driver
//
//
// pdcmd.h contains structures fro PowerDAQ user-level
// library
//
//
// #include "powerdaq.h"

// Command to access the board
// Make shure that additional "high-level" commands
// are not conflictiong with FW commands in pdfw_def.h
//
#define  AINSETSYNCCFG  0xF101
#define  AINREADSCAN    0xF102


// Analog Input synchronous operation structure
// return averaged channel values in dwChList
typedef struct
{
  uint32_t dwMode;
  uint32_t dwChListSize;
  uint32_t dwChList[PD_MAX_CL_SIZE];

} TAinSyncCfg, *PTAinSyncCfg;

typedef struct
{
  uint32_t dwAInCfg;
  uint32_t dwEventsNotify;
  uint32_t dwAInPreTrigCount;
  uint32_t dwAInPostTrigCount;
  uint32_t dwCvRate;
  uint32_t dwClRate;
  uint32_t dwChListSize;
  uint32_t dwChList[PD_MAX_CL_SIZE];

} TAinAsyncCfg, *PTAinAsyncCfg;

// Board hardware event words.
typedef struct
{
    uint32_t   Board;
    uint32_t   ADUIntr;
    uint32_t   AIOIntr;
    uint32_t   AInIntr;
    uint32_t   AOutIntr;

} TEvents, * PTEvents;


typedef struct
{
    unsigned long MaxSize;
    unsigned long WordsRead;
    uint16_t Buffer[PD_EEPROM_SIZE];

} TEepromAcc;


// Main command structure
// union contains ioctl-specific information needed to communicate
// with the driver
//
typedef union {
     TAinSyncCfg  AinSyncCfg;
     TEvents      Event;
     uint32_t     dwParam[8];
     TEepromAcc   EepromAcc;
     TAinAsyncCfg AinAsyncCfg;

} TCmd, *PTCmd;




#endif


