unit DgOut;

interface

uses
{$IFDEF MSWINDOWS}
   Windows, Forms,
{$ENDIF}
{$IFDEF LINUX}
   QForms,
{$ENDIF}
   SysUtils, Classes,
   DAQDefs,
{$IFNDEF DemoModule}
   pwrdaq32, pwrdaq_struct, pwrdaq_LinuxAPI,
{$ELSE}
   PD32Interface,
{$ENDIF}
   pdfw_def, pd_hcaps;

type

  // base acquisition thread
  TDigitalOutput = class(TThread)
  private
    hAdapter: DWORD;
    dwError: DWORD;
    FFrequency: DWORD;
    FOnUpdateView: TUpdateViewProc;
    FOnGetData: TDataFunction;
  protected
    procedure DoTerminate; override;
  public
    constructor Create(Adapter: DWORD);
    procedure Execute; override;
    property Frequency: DWORD read FFrequency write FFrequency;
    property OnUpdateView: TUpdateViewProc read FOnUpdateView write FOnUpdateView;
    property OnGetData: TDataFunction read FOnGetData write FOnGetData;
  end;

implementation

constructor TDigitalOutput.Create(Adapter: DWORD);
begin
  hAdapter := Adapter;
  Frequency := 500;
  FreeOnTerminate := True;
  inherited Create(False);
end;

procedure TDigitalOutput.Execute;
var Value: WORD;
begin
  Value := 0;
  // digital output - init sequence
  try
    // initialize DOut subsystem
{$IFDEF MSWINDOWS}
    if not PdAdapterAcquireSubsystem(hAdapter, @dwError, DigitalOut, 1)
{$ENDIF}
{$IFDEF LINUX}
    hAdapter := PdAcquireSubsystem(hAdapter, DigitalOut, 1);
    if(hAdapter < 0)
{$ENDIF}
      then raise TPwrDaqException.Create('PdAdapterAcquireSubsystem', dwError);
    // thread loop
    while not Terminated do try
      // get data value
      if Assigned(OnGetData) then Value := OnGetData;
      // update view
      //if Assigned(OnUpdateView) then OnUpdateView(Value);
      // output data
{$IFDEF MSWINDOWS}
      if not _PdDOutWrite(hAdapter, @dwError, Value)
{$ENDIF}
{$IFDEF LINUX}
      dwError := _PdDOutWrite(hAdapter, Value);
      if(dwError < 0)
{$ENDIF}
        then raise TPwrDaqException.Create('_PdDOutWrite', dwError);
      try Sleep (10000 div Frequency); except end;
    except
      raise;
    end;
  except
    Application.HandleException(Self);
  end;
end;

procedure TDigitalOutput.DoTerminate;
begin
  // stop input sequence
  try
    // release DInp subsystem and close adapter
{$IFDEF MSWINDOWS}
    if not PdAdapterAcquireSubsystem(hAdapter, @dwError, DigitalOut, 0)
{$ENDIF}
{$IFDEF LINUX}
    dwError := PdAcquireSubsystem(hAdapter, DigitalOut, 0);
    if(dwError < 0)
{$ENDIF}
      then raise TPwrDaqException.Create('PdAdapterAcquireSubsystem', dwError);
  except
    // Handle any exception
    Application.HandleException(Self);
  end;
  inherited;
end;

end.

