unit VisualThread;

interface

uses
{$IFDEF MSWINDOWS}
   Windows, Graphics, ExtCtrls,
{$ENDIF}
{$IFDEF LINUX}
   QGraphics, QExtCtrls,
{$ENDIF}
Types, Classes, SysUtils, DAQDefs;

type

  TVisualThread = class(TThread)
  private
    FPaintHeight: Integer;
    FPaintWidth: Integer;
    FPaintRect: TRect;
    FPaintCanvas: TCanvas;
    FGridCanvas: TCanvas;
    FMemCanvas: TCanvas;
    FBuffer: PAnalogInputBuffer;
    FOffset: DWORD;
    FPrevOffset: DWORD;
    FChannel: DWORD;
    FScanSize: DWORD;
    FNumChannels: DWORD;
    FFrameSize: DWORD;
    FViewSize: DWORD;
    FFrameOffset: DWORD;
    PrevSynch: WORD;
    PrevVect: Boolean;
    FXorMask,
    FAndMask,
    FShift: Word;
    procedure SetScanSize(Value: DWORD);
  protected
    procedure DoVisualisation;
  public
    constructor Create(PaintCanvas: TCanvas; PaintRect: TRect);
    procedure Execute; override;
    property Buffer: PAnalogInputBuffer read FBuffer write FBuffer;
    property Offset: DWORD read FOffset write FOffset;
    property Channel: DWORD read FChannel write FChannel;
    property ScanSize: DWORD read FScanSize write SetScanSize;
    property NumChannels: DWORD read FNumChannels write FNumChannels;
    property FrameSize: DWORD read FFrameSize write FFrameSize;
    property XorMask: Word read FXorMask write FXorMask;
    property AndMask: Word read FAndMask write FAndMask;
    property Shift: Word read FShift write FShift;
  end;

implementation

// Basic methods from AcquisitionThread
constructor TVisualThread.Create(PaintCanvas: TCanvas; PaintRect: TRect);
var
  i : Integer;
begin
  // Assign setup
  FPaintCanvas := PaintCanvas;
  FPaintRect := PaintRect;
  // Create back buffer
  FPaintWidth := PaintRect.Right-PaintRect.Left;
  FPaintHeight := PaintRect.Bottom-PaintRect.Top;
  with TImage.Create(nil) do
  begin
    Picture.Bitmap := TBitmap.Create;
    Picture.Bitmap.Width := FPaintWidth;
    Picture.Bitmap.Height := FPaintHeight;
    Canvas.Pen.Color := clLime;
    Canvas.Brush.Color := clBlack;
    FMemCanvas := Canvas;
  end;
  // Create grid
  with TImage.Create(nil) do
  begin
    Picture.Bitmap := TBitmap.Create;
    Picture.Bitmap.Width := FPaintWidth;
    Picture.Bitmap.Height := FPaintHeight;
    Canvas.Pen.Color := clLime;
    Canvas.Brush.Color := clBlack;
    FGridCanvas := Canvas;
    with FGridCanvas do
    begin
      Brush.Color := clBlack;
      Pen.Color := clGray;
      FillRect (PaintRect);
      for i:=1 to 9 do
      begin
        MoveTo(Round(i * FPaintWidth / 10), PaintRect.Top);
        LineTo(Round(i * FPaintWidth / 10), PaintRect.Bottom);
      end;
      for i:=1 to 9 do
      begin
        MoveTo(PaintRect.Left, Round(i * FPaintHeight / 10));
        LineTo(PaintRect.Right, Round(i * FPaintHeight / 10));
      end;
    end;
  end;
  inherited Create(True);
  FreeOnTerminate := True;
end;

procedure TVisualThread.Execute;
begin
  while not Terminated do
  begin
    Sleep(33);
    Synchronize(DoVisualisation);
  end;
end;

procedure TVisualThread.SetScanSize(Value: DWORD);
begin
  if FScanSize <> Value then
  begin
    FScanSize := Value;
    // view size in samples
    FViewSize := FScanSize * FPaintWidth;
  end;
end;

procedure TVisualThread.DoVisualisation;
const
    DeltaSynch = 5;
var x, i : Integer;
    Value, Synch: Word;
    Vect: Boolean;
begin
  if Buffer <> nil then
  try
    // in low frequency process buffer walking
    if Offset = FPrevOffset then
      if FFrameOffset + FViewSize*2 <= FrameSize
        then Inc(FFrameOffset, FViewSize)
        else FFrameOffset := 0;

    FPrevOffset := FOffset;
    // draw oscilloscope
    with FMemCanvas do
    begin
      // clear background
      CopyRect(FPaintRect, FGridCanvas, FPaintRect);

      // very simple synchronization
      i := 1;
      repeat
        Synch  := ((Buffer^[ (FOffset * FScanSize) + (FFrameOffset) + (i * FScanSize) + Channel] and AndMask) xor XorMask) shr Shift;
        Vect := Synch > ((Buffer^[ (FOffset * FScanSize) + (FFrameOffset) + ((i+DeltaSynch) * FScanSize) + Channel] and AndMask) xor XorMask) shr Shift;
        Inc(i);
      until (i > FPaintWidth) or ((Synch <= PrevSynch) and (Vect = PrevVect));
      PrevSynch := Synch;
      PrevVect := Vect;
      Dec(i);      
      // draw oscilliscope
      for x := 0 to FPaintWidth do
      try
        Value := ((Buffer^[ (FOffset * FScanSize) + (FFrameOffset) + (i * FScanSize) + Channel] and AndMask) xor XorMask) shr Shift;
        if x=0 then MoveTo( x, FPaintHeight - Value - 1) else LineTo( x, FPaintHeight - Value - 1);
        Inc(i);
      except
      end;
    end;
    FPaintCanvas.CopyRect(FPaintRect, FMemCanvas, FPaintRect);
  except
  end;
end;

end.